aj
aj
Functions
| Name | Description |
|---|---|
| prepare_event_table | Generate the full event table from raw times and reals data. |
prepare_event_table
aj.prepare_event_table(times_and_reals)Generate the full event table from raw times and reals data.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| times_and_reals | pl.DataFrame | A Polars DataFrame containing at least times and reals columns. |
required |
Returns
| Name | Type | Description |
|---|---|---|
| pl.DataFrame | The event table with all intermediate columns computed. |